@@ -204,6 +204,9 @@ class GoEnvironment(BaseEnvironment):
             else:
                 return
 
+    def set_annotation(self, svc_name, annotation):
+        return self.client.set_annotation(svc_name, 'service', annotation)
+
     def status(self):
         return self.client.get_stat()
 
