@@ -7,6 +7,17 @@ class Service(object):
     def __repr__(self):
         return "<Service %s>" % (self.name)
 
+    @property
+    def annotations(self):
+        a = self.svc_data.get('annotations')
+        if a is None:
+            return a
+        # core annotations only supports string key / values
+        d = {}
+        for k, v in a.items():
+            d[str(k)] = str(v)
+        return d
+
     @property
     def config(self):
         return self.svc_data.get('options', None)
