@@ -51,8 +51,9 @@ class UtilTests(Base):
         # call succeeds after the 3rd try
         _e = CalledProcessError(returncode=1, cmd=['maybe_fail'])
         check_output.side_effect = [
-            _e, _e, 'good', _e ]
-        output = _check_call(params=['magybe_fail'], log=MagicMock(), max_retry=3)
+            _e, _e, 'good', _e]
+        output = _check_call(
+            params=['magybe_fail'], log=MagicMock(), max_retry=3)
         self.assertEquals(output, 'good')
         # 1 failure + 3 retries
         self.assertEquals(len(check_output.call_args_list), 3)
